cwvreg.py
branchstable
changeset 6152 6824f8b61098
parent 6046 3fd4a34c4a09
child 6162 76bd320c5ace
--- a/cwvreg.py	Wed Aug 25 19:01:58 2010 +0200
+++ b/cwvreg.py	Thu Aug 26 10:13:48 2010 +0200
@@ -161,14 +161,14 @@
 'primary'`) view (`__registry__ = 'views'`) for a result set
 containing a `Card` entity, two objects will probably be selectable:
 
 * the default primary view (`__select__ = implements('Any')`), meaning
   that the object is selectable for any kind of entity type
 
 * the specific `Card` primary view (`__select__ = implements('Card')`,
   meaning that the object is selectable for Card entities
 
 Other primary views specific to other entity types won't be selectable in this
-case. Among selectable objects, the `implements('Card')` selector will return a higher
+case. Among selectable objects, the `is_instance('Card')` selector will return a higher
 score since it's more specific, so the correct view will be selected as expected.
 
 .. _SelectionAPI:
@@ -161,14 +161,14 @@
 containing a `Card` entity, two objects will probably be selectable:
 
-* the default primary view (`__select__ = implements('Any')`), meaning
+* the default primary view (`__select__ = is_instance('Any')`), meaning
   that the object is selectable for any kind of entity type
 
@@ -161,14 +161,14 @@
   that the object is selectable for any kind of entity type
 
-* the specific `Card` primary view (`__select__ = implements('Card')`,
+* the specific `Card` primary view (`__select__ = is_instance('Card')`,
   meaning that the object is selectable for Card entities
 